==> sddm_0.17.0.orig.tar.gz: sddm-0.17.0/data/translations/da.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="da">
<context>
    <name>PictureBox</name>
    <message>
        <source>Press to login</source>
        <translation>Tryk for at logge ind</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>%1 (Wayland)</source>
        <translation>%1 (Wayland)</translation>
    </message>
</context>
<context>
    <name>TextConstants</name>
    <message>
        <source>Warning, Caps Lock is ON!</source>
        <translation>Advarsel, Caps Lock er slået til!</translation>
    </message>
    <message>
        <source>Layout</source>
        <translation>Tastatur</translation>
    </message>
    <message>
        <source>Login</source>
        <translation>Log ind</translation>
    </message>
    <message>
        <source>Login failed</source>
        <translation>Indlogning fejlede</translation>
    </message>
    <message>
        <source>Login succeeded</source>
        <translation>Indlogning lykkedes</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Adgangskode</translation>
    </message>
    <message>
        <source>Enter your username and password</source>
        <translation>Indtast dit brugernavn og adgangskode</translation>
    </message>
    <message>
        <source>Select your user and enter password</source>
        <translation>Vælg din bruger og indtast adgangskode</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Genstart</translation>
    </message>
    <message>
        <source>Session</source>
        <translation>Session</translation>
    </message>
    <message>
        <source>Shutdown</source>
        <translation>Luk ned</translation>
    </message>
    <message>
        <source>User name</source>
        <translation>Brugernavn</translation>
    </message>
    <message>
        <source>Welcome to %1</source>
        <translation>Velkommen til %1</translation>
    </message>
</context>
</TS>

==> sddm_0.19.0.orig.tar.gz: sddm-0.19.0/data/translations/da.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="da">
<context>
    <name>PictureBox</name>
    <message>
        <source>Press to login</source>
        <translation>Tryk for at logge ind</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>%1 (Wayland)</source>
        <translation>%1 (Wayland)</translation>
    </message>
</context>
<context>
    <name>TextConstants</name>
    <message>
        <source>Welcome to %1</source>
        <translation>Velkommen til %1</translation>
    </message>
    <message>
        <source>Warning, Caps Lock is ON!</source>
        <translation>Advarsel, Caps Lock er slået til!</translation>
    </message>
    <message>
        <source>Layout</source>
        <translation>Tastatur</translation>
    </message>
    <message>
        <source>Login</source>
        <translation>Log ind</translation>
    </message>
    <message>
        <source>Login failed</source>
        <translation>Indlogning mislykkedes</translation>
    </message>
    <message>
        <source>Login succeeded</source>
        <translation>Indlogning lykkedes</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Adgangskode</translation>
    </message>
    <message>
        <source>Enter your username and password</source>
        <translation>Indtast dit brugernavn og adgangskode</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Genstart</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Hvile</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation>Dvale</translation>
    </message>
    <message>
        <source>Session</source>
        <translation>Session</translation>
    </message>
    <message>
        <source>Shutdown</source>
        <translation>Luk ned</translation>
    </message>
    <message>
        <source>User name</source>
        <translation>Brugernavn</translation>
    </message>
    <message>
        <source>Enter your username</source>
        <translation>Indtast dit brugernavn</translation>
    </message>
    <message>
        <source>Enter your password</source>
        <translation>Indtast din adgangskode</translation>
    </message>
    <message>
        <source>Select your user and enter password</source>
        <translation>Vælg din bruger og indtast adgangskode</translation>
    </message>
    <message>
        <source>Show password</source>
        <translation>Vis adgangskode</translation>
    </message>
    <message>
        <source>Hide password</source>
        <translation>Skjul adgangskode</translation>
    </message>
    <message>
        <source>Please enter a password!</source>
        <translation>Indtast venligst en adgangskode!</translation>
    </message>
    <message>
        <source>Change password</source>
        <translation>Skift adgangskode</translation>
    </message>
    <message>
        <source>Unregistered user</source>
        <translation>Uregistreret bruger</translation>
    </message>
    <message>
        <source>Password change aborted because maximum tries reached</source>
        <translation>Ændring af adgangskode blev afbrudt da højeste antal forsøg blev nået</translation>
    </message>
    <message>
        <source>New password change round! Please input current password again!</source>
        <translation>Ny runde til ændring af adgangskode! Indtast venligst den nuværende adgangskode igen!</translation>
    </message>
</context>
</TS>
